// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIorwYJKoZIhvcNAQcCoIIooDCCKJwCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAA3zJ9rztB1muCAAA
// SIG // AAADfDANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIzMDUxMTE5MDMzMloX
// SIG // DTI0MDUwODE5MDMzMlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAM7wia8MfPwd4mtILpj8qoFF
// SIG // 2NU9AGUh6KMxjoH5wsKo/CNMznlw6z6QDoXMd1SjRH/n
// SIG // mWLJ9UwKsIHC4wjcIIQA2oTK9wiBP2C4JADckr1ib5QF
// SIG // VIdjt1rgvt7QVuVcu3i+7vIlThcWBQFDCipaAmlQG5WS
// SIG // Lf3DbJZuL5FNO5hxjw5mqtZg/RifUhMu6gw/ZandJNcC
// SIG // 3TW3ZkLpWhjKdJIJh6omc+RYTQByB3XUt4P1wTh4Ah2w
// SIG // ImmwDnQMiHYgLiKTaP1TQBTbmB1o4ims4knVLsfrXKhR
// SIG // UumxtoBIN/YyvhwpJuXqJWTgUq13YyqxNEyNC1QWtGpc
// SIG // Ww+jSkX2sX6yNkxKexr1D+2lyu5C4nNHEox0huDXcn4C
// SIG // eEpERgkVAnxhPLB68NLqqzBa7kLv5V8cNl9rG2FE64AG
// SIG // QA9WxNNUiIt+ItJUgq1IF2t7tdJGvmsJDj07yV0TToU6
// SIG // 5kqUexgpLaDoZizsV4ZhPYjWHpv0D6juvnBPTt4ionDc
// SIG // nFsv9wIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFFKpamFH
// SIG // SEZcQyIedxp5ANsBMD5JMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys1MDEwMTUwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQAOSEYc1GtkOHuaEONN2ZhGwBfVVOls91pV
// SIG // 9txVvKdJwl8XjM3UD80N0c4mvoVT6K1a8VgJom58eg7c
// SIG // 6HuwPsdvhNlaslOhXnFTHGUqJ++gXPDgH5a2w5j0IHTm
// SIG // yYkSv4NDSi9u2FtgWRjlfyag9r8kvBRUv/M8ISO2dqne
// SIG // LiQhJcTL95mFcpt7Jf2m+b25wM6S5BPvV4sgepZMQwGJ
// SIG // HBANg+w2YUfgQ430mnZHg70iI6V+rMEcPW6jFaf9B/5+
// SIG // vvXlw4yabr32W3ofks4OxTX8HVfRLO8uK/jdCODX2vAa
// SIG // Zeh7YNdtTGqMsOhI6KOW+IAQrUnvEbiRPmPqvgFjAH0e
// SIG // NUr/zy/Xt8gxBranFQdM1gVv57aU/HMtK8L8tpAT0Zjc
// SIG // h/4xE2oHpVdcIPxjISlHQJIL7NtEI0/WPNA7afEiUj8C
// SIG // Ztxg9ivyy/hLd+i4COfhFeraWsxkwM+oKKYpWJJFQTgJ
// SIG // Z8kHhoOTVxoxMseEfUalzoL0C+MHsDdsMn5VQw3LCuoq
// SIG // pnhG6vnN0TMNsbNydBflcBlACOPz+S6QNfp62r0JYWXw
// SIG // BbtRM+3A9dHtD4nqr/ZjtCAG8GdxU220D240BmU5/TZR
// SIG // OHHwPLl4Afmki/uogGvnFyd19wFHHG80gB5N9rsdKUsx
// SIG // hO+CqUzuQeurTLKzf6lKyjOfwYQ2IMpN1zCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghoi
// SIG // MIIaHgIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAADfMn2vO0HWa4IAAAAAAN8MA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCCk0LbOeo0Jl3UzqyYc
// SIG // R3jw0T+iGBzKrXSBXSbuitilgzBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgJifRRXKjDYbOfzZsyi0WexgUVtPp8VIaImP
// SIG // dYZDXGm58yh3Hvaf4jl6aFuOWNKhSKJC/z8dCLxefxBj
// SIG // +4dd9r3bt3AXMGm7ELx+Syl4gqWBAckHuteAZMYefMAZ
// SIG // z2C4CfZqub3esinqHliUqTADnlteN0+Q8mzut0Gqysi8
// SIG // iMRpLRxB40QN+pz/HahnXziC9WGxyh332q+9YQiss4BZ
// SIG // mDV9GTa3ElreUdAPuz3OHl1LukKZZox+AKqYugenltjr
// SIG // EKzMj6pO6pVeUmPzOGrgUkvuylJROzkirYXyeGVSCAFz
// SIG // wdX6SQv3wdBGOdacmJykWDCiYGX0ucg7qY+ApUxwzSp9
// SIG // 8t8ZQH3jWmX7QLrwEqaudRx5hlbplpxPtetu+W/BXAr9
// SIG // 2m3cO63GSQzB83GJs4dU8NRGJf9fEaHqmE0wryjkcpoz
// SIG // M0JXptFZsNy0lASy0dvaURGqgwjpcnKX8JNXBZV66SVK
// SIG // UXKb5G1ayJE2gn9ngQYkv3j21NnHrZjTcNTN7aGCFyww
// SIG // ghcoBgorBgEEAYI3AwMBMYIXGDCCFxQGCSqGSIb3DQEH
// SIG // AqCCFwUwghcBAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFZ
// SIG // BgsqhkiG9w0BCRABBKCCAUgEggFEMIIBQAIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCAAybi9x/bE
// SIG // j/4NacSM0veG56NqU7G3bioZrAlE5F+ghQIGZS/fjwOk
// SIG // GBMyMDIzMTAyNDIwMTYzMC4yMzhaMASAAgH0oIHYpIHV
// SIG // MIHSMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRN
// SIG // aWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRpb25zIExpbWl0
// SIG // ZWQxJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOjhENDEt
// SIG // NEJGNy1CM0I3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGlt
// SIG // ZS1TdGFtcCBTZXJ2aWNloIIRezCCBycwggUPoAMCAQIC
// SIG // EzMAAAGz/iXOKRsbihwAAQAAAbMwDQYJKoZIhvcNAQEL
// SIG // BQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
// SIG // TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwHhcN
// SIG // MjIwOTIwMjAyMjAzWhcNMjMxMjE0MjAyMjAzWjCB0jEL
// SIG // MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
// SIG // EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
// SIG // c29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9z
// SIG // b2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMSYw
// SIG // JAYDVQQLEx1UaGFsZXMgVFNTIEVTTjo4RDQxLTRCRjct
// SIG // QjNCNzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEBBQADggIP
// SIG // ADCCAgoCggIBALR8D7rmGICuLLBggrK9je3hJSpc9CTw
// SIG // bra/4Kb2eu5DZR6oCgFtCbigMuMcY31QlHr/3kuWhHJ0
// SIG // 5n4+t377PHondDDbz/dU+q/NfXSKr1pwU2OLylY0sw53
// SIG // 1VZ1sWAdyD2EQCEzTdLD4KJbC6wmAConiJBAqvhDyXxJ
// SIG // 0Nuvlk74rdVEvribsDZxzClWEa4v62ENj/HyiCUX3MZG
// SIG // nY/AhDyazfpchDWoP6cJgNCSXmHV9XsJgXJ4l+AYAgaq
// SIG // AvN8N+EpN+0TErCgFOfwZV21cg7vgenOV48gmG/EMf0L
// SIG // vRAeirxPUu+jNB3JSFbW1WU8Z5xsLEoNle35icdET+G3
// SIG // wDNmcSXlQYs4t94IWR541+PsUTkq0kmdP4/1O4GD54Zs
// SIG // J5eUnLaawXOxxT1fgbWb9VRg1Z4aspWpuL5gFwHa8UNM
// SIG // RxsKffor6qrXVVQ1OdJOS1JlevhpZlssSCVDodMc30I3
// SIG // fWezny6tNOofpfaPrtwJ0ukXcLD1yT+89u4uQB/rqUK6
// SIG // J7HpkNu0fR5M5xGtOch9nyncO9alorxDfiEdb6zeqtCf
// SIG // cbo46u+/rfsslcGSuJFzlwENnU+vQ+JJ6jJRUrB+mr51
// SIG // zWUMiWTLDVmhLd66//Da/YBjA0Bi0hcYuO/WctfWk/3x
// SIG // 87ALbtqHAbk6i1cJ8a2coieuj+9BASSjuXkBAgMBAAGj
// SIG // ggFJMIIBRTAdBgNVHQ4EFgQU0BpdwlFnUgwYizhIIf9e
// SIG // Bdyfw40wHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXSZacb
// SIG // UzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3
// SIG // dy5taWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljcm9z
// SIG // b2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSku
// SIG // Y3JsMGwGCCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQ
// SIG // aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9j
// SIG // ZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENB
// SIG // JTIwMjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAWBgNV
// SIG // HSUBAf8EDDAKBggrBgEFBQcDCDAOBgNVHQ8BAf8EBAMC
// SIG // B4AwDQYJKoZIhvcNAQELBQADggIBAFqGuzfOsAm4wAJf
// SIG // ERmJgWW0tNLLPk6VYj53+hBmUICsqGgj9oXNNatgCq+j
// SIG // Ht03EiTzVhxteKWOLoTMx39cCcUJgDOQIH+GjuyjYVVd
// SIG // OCa9Fx6lI690/OBZFlz2DDuLpUBuo//v3e4Kns412mO3
// SIG // A6mDQkndxeJSsdBSbkKqccB7TC/muFOhzg39mfijGICc
// SIG // 1kZziJE/6HdKCF8p9+vs1yGUR5uzkIo+68q/n5kNt33h
// SIG // daQ234VEh0wPSE+dCgpKRqfxgYsBT/5tXa3e8TXyJlVo
// SIG // G9jwXBrKnSQb4+k19jHVB3wVUflnuANJRI9azWwqYFKD
// SIG // bZWkfQ8tpNoFfKKFRHbWomcodP1bVn7kKWUCTA8YG2Rl
// SIG // TBtvrs3CqY3mADTJUig4ckN/MG6AIr8Q+ACmKBEm4OFp
// SIG // OcZMX0cxasopdgxM9aSdBusaJfZ3Itl3vC5C3RE97uUR
// SIG // sVB2pvC+CnjFtt/PkY71l9UTHzUCO++M4hSGSzkfu+yB
// SIG // hXMGeBZqLXl9cffgYPcnRFjQT97Gb/bg4ssLIFuNJNNA
// SIG // Jub+IvxhomRrtWuB4SN935oMfvG5cEeZ7eyYpBZ4Dbkv
// SIG // N44ZvER0EHRakL2xb1rrsj7c8I+auEqYztUpDnuq6Bxp
// SIG // BIUAlF3UDJ0SMG5xqW/9hLMWnaJCvIerEWTFm64jthAi
// SIG // 0BDMwnCwMIIHcTCCBVmgAwIBAgITMwAAABXF52ueAptJ
// SIG // mQAAAAAAFTANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJv
// SIG // b3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTAwHhcN
// SIG // MjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgzMjI1WjB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCCAiIwDQYJKoZI
// SIG // hvcNAQEBBQADggIPADCCAgoCggIBAOThpkzntHIhC3mi
// SIG // y9ckeb0O1YLT/e6cBwfSqWxOdcjKNVf2AX9sSuDivbk+
// SIG // F2Az/1xPx2b3lVNxWuJ+Slr+uDZnhUYjDLWNE893MsAQ
// SIG // GOhgfWpSg0S3po5GawcU88V29YZQ3MFEyHFcUTE3oAo4
// SIG // bo3t1w/YJlN8OWECesSq/XJprx2rrPY2vjUmZNqYO7oa
// SIG // ezOtgFt+jBAcnVL+tuhiJdxqD89d9P6OU8/W7IVWTe/d
// SIG // vI2k45GPsjksUZzpcGkNyjYtcI4xyDUoveO0hyTD4MmP
// SIG // frVUj9z6BVWYbWg7mka97aSueik3rMvrg0XnRm7KMtXA
// SIG // hjBcTyziYrLNueKNiOSWrAFKu75xqRdbZ2De+JKRHh09
// SIG // /SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZnkXftnIv231f
// SIG // gLrbqn427DZM9ituqBJR6L8FA6PRc6ZNN3SUHDSCD/AQ
// SIG // 8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEzOUyOArxCaC4Q
// SIG // 6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMYctenIPDC+hIK
// SIG // 12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5C4lh8zYGNRiE
// SIG // R9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6bMURHXLvjflS
// SIG // xIUXk8A8FdsaN8cIFRg/eKtFtvUeh17aj54WcmnGrnu3
// SIG // tz5q4i6tAgMBAAGjggHdMIIB2TASBgkrBgEEAYI3FQEE
// SIG // BQIDAQABMCMGCSsGAQQBgjcVAgQWBBQqp1L+ZMSavoKR
// SIG // PEY1Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cVXQBeYl2D9OXS
// SIG // ZacbUzUZ6XIwXAYDVR0gBFUwUzBRBgwrBgEEAYI3TIN9
// SIG // AQEwQTA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9Eb2NzL1JlcG9zaXRvcnku
// SIG // aHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQB
// SIG // gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAP
// SIG // BgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP
// SIG // 6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MA0G
// SIG // CSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3hLB9nATEkW+Ge
// SIG // ckv8qW/qXBS2Pk5HZHixBpOXPTEztTnXwnE2P9pkbHzQ
// SIG // dTltuw8x5MKP+2zRoZQYIu7pZmc6U03dmLq2HnjYNi6c
// SIG // qYJWAAOwBb6J6Gngugnue99qb74py27YP0h1AdkY3m2C
// SIG // DPVtI1TkeFN1JFe53Z/zjj3G82jfZfakVqr3lbYoVSfQ
// SIG // JL1AoL8ZthISEV09J+BAljis9/kpicO8F7BUhUKz/Aye
// SIG // ixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4sa3tuPywJeBTp
// SIG // kbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6MhrZlvSP9pEB
// SIG // 9s7GdP32THJvEKt1MMU0sHrYUP4KWN1APMdUbZ1jdEgs
// SIG // sU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lUZNlz138eW0QB
// SIG // jloZkWsNn6Qo3GcZKCS6OEuabvshVGtqRRFHqfG3rsjo
// SIG // iV5PndLQTHa1V1QJsWkBRH58oWFsc/4Ku+xBZj1p/cvB
// SIG // QUl+fpO+y/g75LcVv7TOPqUxUYS8vwLBgqJ7Fx0ViY1w
// SIG // /ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr4A245oyZ1uEi
// SIG // 6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvpe784cETRkPHI
// SIG // qzqKOghif9lwY1NNje6CbaUFEMFxBmoQtB1VM1izoXBm
// SIG // 8qGCAtcwggJAAgEBMIIBAKGB2KSB1TCB0jELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9zb2Z0IEly
// SIG // ZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMSYwJAYDVQQL
// SIG // Ex1UaGFsZXMgVFNTIEVTTjo4RDQxLTRCRjctQjNCNzEl
// SIG // MCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2Vy
// SIG // dmljZaIjCgEBMAcGBSsOAwIaAxUAcYtE6JbdHhKlwkJe
// SIG // KoCV1JIkDmGggYMwgYCkfjB8MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBQQ0EgMjAxMDANBgkqhkiG9w0BAQUFAAIFAOjiRggw
// SIG // IhgPMjAyMzEwMjQyMTMyNTZaGA8yMDIzMTAyNTIxMzI1
// SIG // NlowdzA9BgorBgEEAYRZCgQBMS8wLTAKAgUA6OJGCAIB
// SIG // ADAKAgEAAgIVlwIB/zAHAgEAAgISEjAKAgUA6OOXiAIB
// SIG // ADA2BgorBgEEAYRZCgQCMSgwJjAMBgorBgEEAYRZCgMC
// SIG // oAowCAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqGSIb3
// SIG // DQEBBQUAA4GBAGSx5ivm9nelcImQvwlTSzy+oJmyt7D/
// SIG // 8TdSCfzDfqo+Kl8QkMbkPwNeTWNSzJLRCiAkCtu0rIWV
// SIG // ldvMdQCDSAYbXZM7BAL4QKbEvlpUBJ0i7u9bLhAValXA
// SIG // ho3HtQYuHCWtEaHf4YwKr5FqPEguH7hM5cKuw5oFKa41
// SIG // tjG1hv+CMYIEDTCCBAkCAQEwgZMwfDELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUt
// SIG // U3RhbXAgUENBIDIwMTACEzMAAAGz/iXOKRsbihwAAQAA
// SIG // AbMwDQYJYIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJ
// SIG // AzENBgsqhkiG9w0BCRABBDAvBgkqhkiG9w0BCQQxIgQg
// SIG // Kcii34a47NCXIUppRnsU9mn51BJE/8HMxA8hC99Sp1sw
// SIG // gfoGCyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCCGoTPV
// SIG // KhDSB7ZG0zJQZUM2jk/ll1zJGh6KOhn76k+/QjCBmDCB
// SIG // gKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMT
// SIG // HU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMz
// SIG // AAABs/4lzikbG4ocAAEAAAGzMCIEIJ+U8PK/jk4sF+XS
// SIG // wo5Eai6svB51kF2pmv7DNuPfw/V4MA0GCSqGSIb3DQEB
// SIG // CwUABIICAEePRk+SgkrZgBkCmTU5pzs2KTNHK0n6+m/H
// SIG // dVy4Dz/F6RLCs3LMSWmxlEPtSZ+socCZ6tntfSYHULRh
// SIG // O4DIciUYtUQuXa6A4egfyi2ySbidRDl64uDlaiVDhtyX
// SIG // QXlZp/MryPXrNj+Fc+0oRmJIJVfi/f4kIb+cK2hw6N7k
// SIG // UofTZSm/VhBlk+HkS+gO+sDfGfJb2ON5xEI78vnZv1eq
// SIG // fdxhQCFW9FEMXiM53lNfvAGGaY+2MPB3+AShl29os7DA
// SIG // f+i4p9w0SU0SVjcA7DunRFdNhDEqMSO+Xj7w63/XY6W9
// SIG // PYqezyJs4cl7kojhKpmIXB7K2tdROb9l6xur2oDyLx8u
// SIG // XSI/xwR0eiWNkiAinAYO0SPdwbKj8fz5HyZnXUqRDkPY
// SIG // h+x/bp/NgLtjy2yO6yrpFMlyNm6P6eEV/7x+5iHXWV6H
// SIG // Chb9NBcnSaGQCwgaw01W9+9py7naJ3oSys+bGRSV+c1f
// SIG // s1uIY5LEhRLaOzV74+6GWm+5uqbUW5ldNai4s6bjBYEu
// SIG // csU8xfmHkLjpsq80UPhclEskbOSjElBDTisO/szmoRHX
// SIG // FUkPMk+voKU0MLbSN0wjk+A2Mcv4VTNV1T5NRMCydTBc
// SIG // h5q+zar9jxlj6DFG+DyJHUlzffhApVbfOrleQ2WQRwni
// SIG // h0902OMC1ZjgEgzi8/+l0iPVbniK3or6
// SIG // End signature block
